@@ -1,15 +1,3 @@
-getPassEnv <- new.env()
-
-
-
-print_stderr <- function(msg)
-{
-  ret <- .Call(getPass_print_stderr, msg)
-  invisible(ret)
-}
-
-
-
 isaterm <- function()
 {
   gui <- .Platform$GUI
